# rmtoo-art-tlp

NAME
DESCRIPTION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-art-tlp1 - requirements management tool: tulip version 1 output

## DESCRIPTION

This output module privides an interface to the graph visualization software tulip. With tulip it is possible to vizualize the requirements dependencies using different graph layouts.

Note that tulip works with graphs and not with digraphs. Therefore the direction of the dependency cannot be visualized.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

tulip(1) - graph visualization

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2011 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later